import { gantt } from '@dhtmlxgantt'
// import '@ganttApi'
import '@/assets/css/dhtmlxgantt.css'
// import 'dhtmlx-gantt/codebase/dhtmlxgantt.css'
import dayjs from 'dayjs'
import { i18n } from '@/locales/setupI18n'

// gantt.config.autosize = false
gantt.config.readonly = true
// 是否显示左侧树表格
gantt.config.show_grid = true
// 时间轴边框
gantt.config.show_task_cells = true
gantt.config.fit_tasks = true
// gantt.config.duration_unit = 'day'
gantt.config.grid_width = 300
gantt.config.scale_height = 50
// 时间轴图表中，任务条形图的高度
gantt.config.task_height = 28
// 时间轴图表中，甘特图的高度
gantt.config.row_height = 26
// 从后端过来的数据格式化
gantt.config.xml_date = '%Y-%m-%d'

gantt.templates.task_text = function(start, end, task) {
  // return `<div title='${task.name}，完成计划： ${Math.round(task.progress * 100)}%'><b style='text-align:left;'>名称:</b> ${task.name}<span style='text-align:left;'>完成计划： ${Math.round(task.progress * 100)}% </span></div>`
  // return `<div title='${task.name}'><b style='text-align:left;'>名称:</b> ${task.name}<span style='text-align:left;'>完成计划： ${Math.round(task.progress * 100)}% </span></div>`
  return `<div title='${task.name}：${Math.round(task.progress * 100)}%'>${task.name}：<span style='text-align:left;'>${Math.round(task.progress * 100)}% </span></div>`
}
gantt.templates.tooltip_text = function(start, end, task) {
  // return `<b>任务名称:</b> ${task.name}<br/><b>时长:</b> ${task.duration}<br/><b>说明:</b>${task.toolTipsTxt}`
  return false
}

gantt.templates.task_class = function(start, end, task) {
  /**
   * 设置超期 红色背景：当前时间 > 结束时间
   * 设置临期 黄色背景：当前时间 < 结束时间，0 到 3天内
   */
  // 获取两个日期之间隔的天数的数量
  const num = (dayjs(new Date()).diff(end, 'day') - 1)
  if (task.progress < 1) {
    if (num > 0) {
      return 'hid-gantt-overdue'
    } else if (num <= 0 && num > -3) {
      return 'hid-gantt-neartask'
    }
  }
  return task.$level === 0 ? 'firstLevelTask' : 'secondLevelTask'
}

gantt.plugins({
  tooltip: true,
  // drag_timeline: true
})
gantt.attachEvent('onGanttReady', function() {
  var tooltips = gantt.ext.tooltips
  // tooltips.tooltip.setViewport(gantt.$task_data)
  tooltips.tooltipFor({
    selector: '.gantt_task_link',
    html: function(event, node) {
      const linkId = node.getAttribute(gantt.config.link_attribute)
      if (linkId) {
        const link = gantt.getLink(linkId)
        const from = gantt.getTask(link.source)
        const to = gantt.getTask(link.target)
        const toPreTasks = to.preTasks
        const currentRely = toPreTasks.find(obj => obj.previousId === from.stringId)
        const currentRelyText = currentRely.index + currentRely.rely + '+' + currentRely.spaceDays

        // i18n
        const tlink = i18n.global.t('pmPlan.drawerIndex.dely')
        const tfrom = i18n.global.t('common.from')
        const tto = i18n.global.t('common.to')
        const tindex = i18n.global.t('columns.index')
        return [
          `<b>${tlink}：</b> ${currentRelyText}`, // linkTypeToString(link.type)
          `<b>${tfrom}： </b> ${tindex}${from.index}：${from.name}`,
          `<b>${tto}： </b> ${tindex}${to.index}：${to.name}`
        ].join('<br>')
      }
    }
  })
})

/* gantt.config.drag_timeline = {
  ignore: '.gantt_task_line, .gantt_task_link',
  useKey: false
} */

export default gantt
