import { reactive, onMounted, toRefs } from 'vue'
import gantt from '../gantt-config'
import store from '@/store'
import { i18n } from '@/locales/setupI18n'
// import { nextTick } from 'vue/types/umd'

function useGantt(data, df) {
  const state = reactive({
    currentScale: 'mini'
  })
  const weekScaleTemplate = function(date) {
    const dateToStr = gantt.date.date_to_str('%Y/%m/%d')
    const endDate = gantt.date.add(gantt.date.add(date, 1, 'week'), -1, 'day')
    return dateToStr(date) + ' - ' + dateToStr(endDate)
  }
  const daysStyle = function(date) {
    if (date.getDay() === 0 || date.getDay() === 6) return 'hid-gantt-weekend'
    return ''
  }
  const weekLan = i18n.global.t('common.week')
  const yearLan = i18n.global.t('common.year')
  const scalelevel = {
    mini: [
      { unit: 'week', step: 1, format: weekScaleTemplate },
      { unit: 'day', step: 1, date: '%d %D', css: daysStyle }
    ],
    small: [
      { unit: 'month', step: 1, date: '%Y/%m' },
      { unit: 'week', step: 1, date: `%W${weekLan}` },
    ],
    medium: [
      { unit: 'year', step: 1, date: '%Y' },
      { unit: 'month', step: 1, date: '%M' },
    ],
    big: [
      { unit: 'year', step: 1, date: `%Y${yearLan}` },
    ],
  }
  const keymapUp = {
    big: 'medium',
    medium: 'small',
    small: 'mini'
  }
  const keymapDown = {
    mini: 'small',
    small: 'medium',
    medium: 'big'
  }
  const ganttShrink = (d) => {
    const c = state.currentScale
    if (d === 'up') {
      state.currentScale = keymapUp[c]
    } else {
      state.currentScale = keymapDown[c]
    }
    gantt.config.scales = scalelevel[state.currentScale]
    gantt.render()
  }

  const ganttClearAll = () => {
    gantt.clearAll()
  }

  const ganttColumnsDefine = () => {
    gantt.config.columns = [
      { name: 'index', label: i18n.global.t('columns.index'), width: '40', align: 'center' },
      { name: 'name', label: i18n.global.t('pmPlan.columns.name'), tree: true, width: '180' },
      {
        name: 'durationgtu',
        label: i18n.global.t('pmPlan.columns.duration'),
        align: 'center',
        width: '50',
        template: function(obj) {
          return obj.durationgtu + i18n.global.t('common.day')
        }
      },
      { name: 'start_date', label: i18n.global.t('pmPlan.columns.planDateStart'), align: 'center', width: '100' },
      {
        name: 'end_date',
        label: i18n.global.t('pmPlan.columns.planDateEnd'),
        align: 'center',
        width: '100',
        template: function(obj) {
          return obj.rememberEndDate
        }
      },
    ]
  }
  // const ganttExportToPDF = () => {
  //   gantt.exportToPDF()
  // }
  onMounted(() => {
    ganttClearAll()
    // alert(store.getters['locale/currentLocale'])
    ganttColumnsDefine()
    store.getters['locale/currentLocale'] === 'zh' && gantt.i18n.setLocale('cn')
    gantt.config.scales = scalelevel[state.currentScale]
    gantt.init(df.value)
    /* nextTick(() => {

    }) */
    /* data.data.forEach(obj => {
      obj.duration = 4
    }) */
    // nextTick(() => {
    /* const currentTasksData = data.data
    if (currentTasksData.length > 0) {
      currentTasksData.forEach(obj => {
        if (obj.duration) obj.duration = obj.durationgtu
        var dd = new Date(obj.end_)
        // 将当前日期
        dd.setDate(dd.getDate() + 1)
      })
      console.log('数据：：', data)
    } */
    gantt.parse(data)
    gantt.eachTask(function(task) {
      task.$open = true
    })
    gantt.render()
    // })
  })
  return {
    ...toRefs(state),
    ganttShrink,
    ganttClearAll,
    // ganttExportToPDF
  }
}

export default useGantt
