import { getUserIvidSettingData, /* addUserIvidSettingData */ } from '@/api/user'
import { getLov, getLovList } from '@/api/common'
import { reactive } from 'vue'
import store from '@/store'
import useAsync from '@/hooks/useAsync'

/**
 * 查询lov公共接口
 * @param data
 */
const getLovApi = (data) => {
  return new Promise((resolve, reject) => {
    if (data !== null) {
      const key = 'LOV_id' + data
      const localData = store.state.app.lov[key]
      if (localData) {
        resolve(localData)
      }
      getLov({ id: data }).then((res) => {
        if (res && res.isSuccess) {
          store.dispatch('app/addLov', {
            key,
            value: res.data
          })
          return res.data
        } else {
          return null
        }
      }).catch((e) => {
        resolve(null)
      })
    } else {
      resolve(null)
    }
  })
}

/**
 * 查询lovlist公共接口
 * @param data
 */
const getLovListApi = (data, type) => {
  return new Promise((resolve, reject) => {
    if (data !== null) {
      const key = 'LOV_LIST' + data
      const localData = store.state.app.lovList[key]
      if (localData) {
        resolve(localData)
      } else {
        getLovList(data, type).then((res) => {
          if (res && res.isSuccess && res.data.length) {
            store.dispatch('app/addLovList', {
              key,
              value: res.data
            })
            resolve(res.data)
          } else {
            resolve([])
          }
        }).catch((e) => {
          resolve([])
        })
      }
    } else {
      resolve([])
    }
  })
}

const initUserData = (params, callback) => {
  /**
   * 初始化项目显示
   * */
  const localData = store.getters['app/curRightSelectObj']
  if (localData.length === 0) {
    useAsync(async() => {
      const ret = await getUserIvidSettingData('user_project_history')
      if (ret && ret.isSuccess) {
        if (ret.data && ret.data.data) {
          const oneD = { type: 'project', key: 'drawerProjects', row: reactive(ret.data.data), value: false }
          store.commit('app/SET_CURRIGHTSELECTOBJ', oneD)
        }
      }
    }, res => {
      if (callback) callback(res)
    })
  }
}
/**
 * 新增历史列表和最后访问数据
 * @param key
 * @param p
 */
/* const addUserInvidData = (key, p) => {
  addUserIvidSettingData(key + ':' + p.id, p)
  addUserIvidSettingData(key, p)
} */
export {
  initUserData,
  getLovApi,
  getLovListApi,
  // addUserInvidData
}
