import { i18n } from './setupI18n'
import { unref, computed } from 'vue'
import { setHtmlPageLang } from './helper'
import store from '@/store'

function setI18nLanguage(locale) {
  if (i18n.mode === 'legacy') {
    i18n.global.locale = locale
  } else {
    i18n.global.locale.value = locale
  }
  store.commit('locale/SET_LOCALE', locale)
  setHtmlPageLang(locale)
}

export function useLocale() {
  const getLocale = computed(() => store.getters['locale/currentLocale'])
  const getElementLocale = computed(() => {
    return i18n.global.getLocaleMessage(unref(getLocale.value))?.elementLang ?? {}
  })
  async function changeLocale(locale) {
    const globalI18n = i18n.global
    const currentLocale = unref(globalI18n.locale)
    if (currentLocale === locale) {
      return locale
    }
    setI18nLanguage(locale)
    return locale
  }
  return {
    getLocale,
    changeLocale,
    getElementLocale
  }
}
