import store from '@/store'
import NProgress from 'nprogress'
import 'nprogress/nprogress.css'
import { getToken } from '@/utils/auth'
import { TOKEN_KEY } from '@/constant/app'
import { setDocumentTitle, redirectToSingleLogin } from '@/utils'
import { ElMessage } from 'element-plus'
const whiteList = ['/login', '/401', '/userlogin']

export function hasPermit(to) {
  return !to.meta || !to.meta.auth || (to.meta && to.meta.auth && store.getters['app/userMenus'].some((item) => item.resourcePath === to.path || (item.routeCode && item.routeCode === to.name)))
}
const loginToAccess = async(to, pa) => {
  try {
    await store.dispatch('app/LoginByCode', pa)
    if (!store.getters['app/userInfo']) {
      await store.dispatch('app/GetUserInfo')
    }
    if (!store.getters['app/userAuths']) {
      await store.dispatch('app/getUserAuth')
    }
    // 以下注释代码用于主题切换暂不使用
    // if (!window.__POWERED_BY_QIANKUN__) {
    //   store.dispatch('app/ToggleAppTheme')
    // }
    // 注释下面代码可关闭权限校验
    // if (hasPermit(to)) {
    //   return true
    // } else {
    //   return { path: '/401' }
    // }
    // 关闭权限需打开以下注释代码
    return true
  } catch (err) {
    ElMessage({
      showClose: true,
      message: String(err),
      type: 'error',
      duration: 5 * 1000
    })
    if (!store.getters['app/isQiankun']) {
      store.dispatch('app/LogOut').then(res => {
        redirectToSingleLogin(res, true)
      })
    } else {
      return false
    }
  }
}
export const permissionJudge = (router) => {
  router.beforeEach(async(to) => {
    // 如果是独立运行，启用加载动画，如果做子应用就关闭
    if (!store.getters['app/isQiankun']) {
      NProgress.start()
    }

    /*
    权限逻辑:
    判断是否是白名单，如果是白明单路由直接进入，如果不是检查是否有token，
    如果有，将token存到store中，并且获取用户信息和权限信息存到store，
    如果没有，
    查看路由参数是否有code，
    有code代表是iam登录完成跳转过来的，调用接口获取token，用户信息和权限信息
    没有code说明没有走iam登录，此时需要跳转到m登录链接
    */
    if (whiteList.includes(to.path)) {
      return true
    } else {
      const token = getToken(TOKEN_KEY)
      if (token) {
        return await loginToAccess(to, { login: true })
      } else {
        if (store.getters['app/isQiankun']) {
          return false
        } else {
          if (to.query.code) {
            const code = to.query.code
            return await loginToAccess(to, { code, login: false })
          } else {
            store.dispatch('app/GetLoginWebsite')
          }
        }
      }
    }
  })

  router.afterEach((to) => {
    if (!store.getters['app/isQiankun']) {
      NProgress.done()
      setDocumentTitle(to.meta.title)
    }
  })
}
