import { login, loginByCode, getIamSetting, getAuthBtnsApi, getUserInfo } from '@/api/app'
import { defaultRoutes } from '@/router'
// import _ from 'lodash-es'
import { setStore, getStore } from '@/utils/store'
import { getToken, setToken, removeToken } from '@/utils/auth'
import { TOKEN_KEY, IS_ADMIN, SYS_CODE } from '@/constant/app'
import { handleTree, formateTreeToHorizontal } from '@/utils/treeUtils'
import { redirectToSingleLogin, formatCurrentToken, getUserInfos } from '@/utils'
import useAppTheme from '@/hooks/useAppTheme'
// import jwt from 'jsonwebtoken'
import { i18n } from '@/locales/setupI18n'

// 提示：以下信息为当前用户“userInfo”信息
/* const userData = {
  authorities: ['ABCD31', 'admin'],
  client_id: 'client-app',
  code: 'A0022014',
  departmentCode: 'All',
  departmentName: null,
  exp: 1642145963,
  id: null,
  isAdmin: true,
  jti: '1a00f8a4-2b69-40e6-85e4-da30e78a1311',
  name: 'Admin',
  productDepartmentCode: 'public.product_department.01',
  productDepartmentName: '01-家用空调',
  productLineCode: 'KT',
  productLineId: 39,
  productLineName: '家用空调',
  scope: ['default-scope'],
  user_name: 'A0022014'
} */

const state = {
  isQiankun: false,
  token: '',
  userInfo: null,
  userCode: '',
  roles: null,
  authList: null,
  authMenus: null,
  authRoutes: null,
  // authBtns: null,
  allRoutes: defaultRoutes,
  addRoutes: [],
  buttons: null,
  isCollapse: false,
  loginTimeout: false,
  appTheme: 'light',
  // codeList相关
  lov: {
    // LOV_id1: {},
  },
  lovList: {
    // LOVList_propertyid1: [],
  },
}

const getters = {
  isQiankun: state => state.isQiankun,
  token: state => state.token,
  userInfo: state => state.userInfo,
  userCode: state => state.userCode,
  userAuths: state => state.authList,
  userMenus: state => state.authMenus,
  authRoutes: state => state.authRoutes,
  // userBtns: state => state.authBtns,
  roles: state => state.roles,
  allRoutes: state => state.allRoutes,
  addRoutes: state => state.addRoutes,
  buttons: state => state.buttons,
  isCollapse: state => state.isCollapse,
  loginTimeout: state => state.loginTimeout,
  appTheme: state => state.appTheme,
  lov: state => {
    return (key) => state.lov[key]
  },
  lovList: state => {
    return (key) => state.lovList[key]
  }
}

const mutations = {
  SET_ISQIANKUN: (state, data) => {
    state.isQiankun = data
  },
  SET_USERINFO: (state, userInfo) => {
    state.userInfo = userInfo
    // state.userCode = userInfo.code
    setStore({ name: 'userInfo', type: 's', content: userInfo })
  },
  SET_AUTHLIST(state, value) {
    state.authList = value
  },
  SET_AUTHMENUS(state, value) {
    state.authMenus = value
  },
  SET_AUTHROUTES(state, value) {
    state.authRoutes = value
  },
  // SET_AUTHBTNS(state, value) {
  //   state.authBtns = value
  // },
  SET_USERCODE: (state, data) => {
    state.userCode = data
  },
  SET_USERTOKEN: (state, data) => {
    state.token = data
  },
  SET_ROLES: (state, roles) => {
    state.roles = roles
  },
  SET_ROUTER: (state, route) => {
    state.addRoutes = route
    state.allRoutes = [...defaultRoutes, ...route]
    // state.firstLevelRoutes = state.allRoutes.filter(obj => !obj.hidden)
  },
  SET_BUTTON: (state, data) => {
    const o = {}
    data.forEach(obj => {
      const k = obj.resourcePath
      // o[k] = true
      o[k] = {
        name: obj.resourceName
      }
    })
    state.buttons = JSON.stringify(o) !== '{}' ? o : null
  },
  TOGGLE_APP_THEME: (state, data) => {
    state.appTheme = data
    useAppTheme(data)
  },
  TOGGLE_MENU_COLLAPSE: (state) => {
    state.isCollapse = !state.isCollapse
  },
  RESET_APPDATA: (state, data) => {
    state.userInfo = null
    state.roles = null
    state.allRoutes = defaultRoutes
    state.addRoutes = []
  },
  SET_LOGIN_TIMEOUT: (state, data) => {
    state.loginTimeout = data
  },
  SET_LOV: (state, data) => {
    state.lov[data.key] = data.value
  },
  SET_LOVLIST: (state, data) => {
    state.lovList[data.key] = data.value
  },
}

const actions = {
  ToggleAppTheme({ commit }, data) {
    if (data) {
      commit('TOGGLE_APP_THEME', data)
    } else {
      const t = getStore({ name: 'apptheme' }) || 'light'
      commit('TOGGLE_APP_THEME', t)
    }
  },
  async fetchRoles({ commit }) {
    try {
      // const { code, data } = await getUserRoles()
      const code = 0
      const data = { roles: ['admin'], userInfo: { userName: 'HID测试' } }
      if (code === 0) {
        const roles = data.roles
        const userInfo = data.userInfo
        commit('SET_ROLES', roles)
        commit('SET_USERINFO', userInfo)
        return Promise.resolve(data)
      }
    } catch (err) {
      return Promise.reject(err)
    }
  },
  addLov({ commit }, data) {
    commit('SET_LOV', data)
  },
  addLovList({ commit }, data) {
    commit('SET_LOVLIST', data)
  },
  Login({ commit, state }, data) {
    return new Promise((resolve, reject) => {
      login(data).then(res => {
        if (res.data.access_token) {
          const token = formatCurrentToken(res.data.access_token)
          setToken(TOKEN_KEY, token)
          setToken(IS_ADMIN, token)
          commit('SET_USERTOKEN', token)
        } else {
          reject(i18n.global.t('common.loginFailed'))
        }
        resolve(res)
      }).catch(err => {
        reject(err)
      })
    })
  },
  LoginByCode({ commit, state }, data) {
    return new Promise((resolve, reject) => {
      if (data.login) {
        const token = getToken(TOKEN_KEY)
        commit('SET_USERTOKEN', token)
        // const result = jwt.decode(token)
        // commit('SET_USERINFO', result)
        resolve()
      } else {
        loginByCode(data).then(res => {
          if (res.data.access_token) {
            const token = formatCurrentToken(res.data.access_token)
            setToken(TOKEN_KEY, token)
            commit('SET_USERTOKEN', token)
            // const result = jwt.decode(token)
            // commit('SET_USERINFO', result)
            resolve(res)
          } else {
            reject(i18n.global.t('common.loginFailed'))
          }
        }).catch(err => {
          reject(err)
        })
      }
    })
  },
  GetUserInfo({ commit, state }) {
    return new Promise((resolve, reject) => {
      let info = null
      if (state.isQiankun) {
        info = getUserInfos()
        commit('SET_USERINFO', info)
        resolve(info)
      } else {
        getUserInfo()
          .then(res => {
            if (res.isSuccess) {
              info = res.data || {}
              commit('SET_USERINFO', info)
              const roles = res.data.roleList ? res.data.roleList.map(role => role.roleCode) : []
              commit('SET_ROLES', roles)
              // commit('SET_USERCODE', userCode);
              const obj = {
                content: info,
                dataType: 'object',
                datetime: new Date().getTime(),
                type: 's',
              }
              sessionStorage.setItem('userInfo', JSON.stringify(obj))
              sessionStorage.setItem('userCode', info.userCode)
            }
            resolve(info)
          })
          .catch(e => {
            reject(e)
          })
      }
    })
  },
  getUserAuth({ commit, state }) {
    return new Promise((resolve, reject) => {
      let allList = []; let menuList = []; let btnList = []; let authRoutes = []
      getAuthBtnsApi({ sysCode: SYS_CODE })
        .then(res => {
          if (res.isSuccess) {
            allList = res.data || []
            allList = formateTreeToHorizontal(allList)
            menuList = allList.filter(item => item.menuType === 'menu')
            btnList = allList.filter(item => item.menuType === 'button')
            authRoutes = handleTree(
              menuList.map((item) => {
                return {
                  fullPath: item.resourcePath,
                  path: item.resourcePath,
                  name: item.routeCode,
                  hidden: item.hidden,
                  id: item.id,
                  parentId: item.parentId,
                  meta: {
                    icon: item.icon || '',
                    title: item.resourceName || '',
                  },
                }
              })
            )[0].children
          }
          commit('SET_AUTHLIST', allList)
          commit('SET_AUTHMENUS', menuList)
          commit('SET_BUTTON', btnList)
          commit('SET_AUTHROUTES', authRoutes)
          resolve(res)
        })
        .catch(e => {
          reject(e)
        })
    })
  },
  LogOut({ commit, state }) {
    return new Promise((resolve, reject) => {
      commit('RESET_APPDATA')
      removeToken(TOKEN_KEY)
      removeToken(IS_ADMIN)
      getIamSetting({}).then(res => {
        resolve(res.data || '')
      }).catch(err => {
        reject(err)
      })
    })
  },
  GetLoginWebsite({ commit }) {
    return new Promise((resolve, reject) => {
      getIamSetting({}).then(res => {
        redirectToSingleLogin(res.data)
        resolve(res.data)
      }).catch(err => {
        reject(err)
      })
    })
  },
}

export default {
  namespaced: true,
  state,
  getters,
  mutations,
  actions,
}
