/* eslint-disable prefer-promise-reject-errors */
/* eslint-disable camelcase */
import axios from 'axios'
import { ElMessage } from 'element-plus'
/**
 * get请求方式_query传参
 * @param {请求接口} url
 * @param {请求参数} data
 */
// eslint-disable-next-line camelcase
function request_get_query(url, data) {
  return new Promise((resolve, reject) => {
    const param = new URLSearchParams()
    for (const item in data) {
      param.append(item, data[item])
    }
    axios({
      headers: {
        'Access-Control-Allow-Methods': '*'
      },
      method: 'get',
      url,
      params: param
    }).then((ok) => {
      resolve(ok.data)
    }).catch((err) => {
      // eslint-disable-next-line prefer-promise-reject-errors
      reject()
      ElMessage({
        showClose: true,
        type: 'error',
        message: err.toString()
      })
    })
  })
}

/**
 * post请求方式_body传参
 * @param {请求接口} url
 * @param {请求参数} data
 */
function request_post_body_json(url, data) {
  return new Promise((resolve, reject) => {
    axios({
      headers: {
        'Access-Control-Allow-Methods': '*',
        'Content-Type': 'application/json;'
      },
      method: 'post',
      url,
      data: data
    }).then((ok) => {
      resolve(ok.data)
    }).catch((err) => {
      reject()
      ElMessage({
        showClose: true,
        type: 'error',
        message: err.toString()
      })
    })
  })
}

/**
 * post请求方式_query传参
 * @param {请求接口} url
 * @param {请求参数} data
 */
function request_post_query(url, data) {
  return new Promise((resolve, reject) => {
    const param = new URLSearchParams()
    for (const item in data) {
      param.append(item, data[item])
    }
    axios({
      headers: {
        'Access-Control-Allow-Methods': '*',
      },
      method: 'post',
      url,
      params: param
    }).then((ok) => {
      resolve(ok.data)
    }).catch((err) => {
      reject()
      ElMessage({
        showClose: true,
        type: 'error',
        message: err.toString()
      })
    })
  })
}

/**
 * post请求方式_formData传参
 * @param {*} url
 * @param {*} data
 * @returns
 */
function request_post_formData(url, data) {
  return new Promise((resolve, reject) => {
    axios({
      headers: {
        'Access-Control-Allow-Methods': '*',
      },
      method: 'post',
      url,
      data
    }).then((ok) => {
      resolve(ok.data)
    }).catch((err) => {
      reject()
      ElMessage({
        showClose: true,
        type: 'error',
        message: err.toString()
      })
    })
  })
}

/**
 * post请求方式_body_query传参
 * @param {请求接口} url
 * @param {body请求参数} data
 * @param {query请求参数} params
 * @returns
 */
function request_post_body_query(url, data, params) {
  return new Promise((resolve, reject) => {
    const param = new URLSearchParams()
    for (const item in params) {
      param.append(item, params[item])
    }
    axios({
      headers: {
        'Access-Control-Allow-Methods': '*',
      },
      method: 'post',
      url,
      data,
      params: param
    }).then((ok) => {
      resolve(ok.data)
    }).catch((err) => {
      reject()
      ElMessage({
        showClose: true,
        type: 'error',
        message: err.toString()
      })
    })
  })
}

/**
 * delete请求方式_query传参
 * @param {请求接口} url
 * @param {请求参数} data
 */
function request_delete_query(url, data) {
  return new Promise((resolve, reject) => {
    const param = new URLSearchParams()
    for (const item in data) {
      param.append(item, data[item])
    }
    axios({
      headers: {
        'Access-Control-Allow-Methods': '*'
      },
      method: 'delete',
      url,
      params: param
    }).then((ok) => {
      resolve(ok.data)
    }).catch((err) => {
      reject()
      ElMessage({
        showClose: true,
        type: 'error',
        message: err.toString()
      })
    })
  })
}

/**
 * delete请求方式_body传参
 * @param {请求接口} url
 * @param {请求参数} data
 */
function request_delete_body_json(url, data) {
  return new Promise((resolve, reject) => {
    axios({
      headers: {
        'Access-Control-Allow-Methods': '*',
        'Content-Type': 'application/json;'
      },
      method: 'delete',
      url,
      data: data
    }).then((ok) => {
      resolve(ok.data)
    }).catch((err) => {
      reject()
      ElMessage({
        showClose: true,
        type: 'error',
        message: err.toString()
      })
    })
  })
}

export const request = {
  request_get_query,
  request_post_body_json,
  request_post_query,
  request_post_body_query,
  request_post_formData,
  request_delete_query,
  request_delete_body_json
}
