import axios from 'axios'
// import { router } from '@/router'
import { ElMessage, ElMessageBox } from 'element-plus'
import { TOKEN_KEY } from '@/constant/app'
import { getToken, /* removeToken */ } from '@/utils/auth'
import { redirectToSingleLogin } from '@/utils'
import store from '@/store'

// export default function request(conf) {
const service = axios.create({
  timeout: 30000,
  baseURL: process.env.VUE_APP_BASE_API,
})
service.interceptors.request.use(config => {
  if (store.getters['app/token']) {
    const t = getToken(TOKEN_KEY)
    if (t) {
      config.headers.Authorization = t.includes('Bearer') ? t : `Bearer ${t}`
      config.headers.customLanguage = store.getters['locale/currentLocale']
    }
  }
  return config
},
error => {
  console.log(error) // for debug
  return Promise.reject(error)
})
service.interceptors.response.use((response) => {
  const res = response.data
  // 二进制数据则直接返回
  if (response.request.responseType === 'blob' || response.request.responseType === 'arraybuffer') {
    return res
  }
  if (res.code !== '200') { // 200 is success
    if (res.code === '506') {
      if (!store.getters['app/loginTimeout']) {
        const url = response.config.url
        const isInfoApi = url.includes('/login/getUserViews')
        store.commit('user/SET_LOGIN_TIMEOUT', true)
        if (!isInfoApi) {
          ElMessageBox.confirm('登录信息已过期，请重新登录！', '重新登录', {
            confirmButtonText: '重新登录',
            showCancelButton: false,
            type: 'warning'
          }).then(() => {
            store.dispatch('app/LogOut').then(res => { redirectToSingleLogin(res, true) })
          }).catch(() => {
            store.commit('user/SET_LOGIN_TIMEOUT', false)
          })
        }
        return Promise.reject(res.msg || '重新登录')
      }
    } else {
      if (res.msg) {
        ElMessage({
          message: res.msg || 'Error',
          type: 'error',
          duration: 5 * 1000
        })
      }
      return Promise.reject(new Error(res.msg || 'Error'))
    }
  } else {
    return res
  }
},
error => {
  if (error.response && error.response.data && error.response.data.constructor === Object) {
    const message = error.response.data.message
    const msg = error.response.data.msg
    const code = error.response.data.code
    ElMessage({
      message: message || msg || 'error',
      type: 'error',
      duration: 5 * 1000
    })
    if (code && code === '401') {
      store.dispatch('app/LogOut').then(res => { redirectToSingleLogin(res, true) })
    }
  } else if (error.message.indexOf('Network Error') > -1) {
    ElMessage({
      message: '网络错误，请联系管理员！',
      type: 'error',
      duration: 5 * 1000
    })
  } else {
    ElMessage({
      message: error.message,
      type: 'error',
      duration: 5 * 1000
    })
  }

  return Promise.reject(error)
})

// 通用下载方法
export function download(url, params, filename, method = 'GET') {
  // downloadLoadingInstance = Loading.service({ text: "正在下载数据，请稍候", spinner: "el-icon-loading", background: "rgba(0, 0, 0, 0.7)", })
  const data = {
    url,
    method: method,
    responseType: 'blob'
  }
  if (method.toUpperCase() === 'GET') {
    data.params = params
  } else {
    data.data = params
  }
  return service(data).then((res) => {
    var blob = res
    // var blob = new Blob([res], { type: 'application/vnd.ms-excel; charset=utf-8' }) // application/vnd.openxmlformats-officedocument.spreadsheetml.sheet这里表示xlsx类型
    if (window.navigator.msSaveBlob) { // 没有此判断的话，ie11下的导出没有效果
      window.navigator.msSaveBlob(blob, filename)
    } else {
      var downloadElement = document.createElement('a')
      var href = window.URL.createObjectURL(blob) // 创建下载的链接

      downloadElement.href = href
      downloadElement.download = filename // 下载后文件名

      document.body.appendChild(downloadElement)
      downloadElement.click() // 点击下载

      document.body.removeChild(downloadElement) // 下载完成移除元素

      window.URL.revokeObjectURL(href) // 释放掉blob对象
    }
  }).catch((r) => {
    console.error(r)
    ElMessage({
      message: '下载文件出现错误，请联系管理员！',
      type: 'error',
      duration: 3 * 1000
    })
    // downloadLoadingInstance.close();
  })
}
export default service
// }
